Change log
==========

`Next version`_
~~~~~~~~~~~~~~~

`0.1`_ (2017-12-19)
~~~~~~~~~~~~~~~~~~~

- Initial public version.

.. _0.1: https://github.com/matthiask/django-spark/commit/4b8747afd
.. _Next version: https://github.com/matthiask/django-spark/compare/0.1...master
